pub struct AccountMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on account resources.
It is not used directly, but through the AdSense hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_adsense1d4 as adsense1d4;
use adsense1d4::{AdSense, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = AdSense::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `adclients_get_ad_code(...)`, `adclients_list(...)`, `adunits_customchannels_list(...)`, `adunits_get(...)`, `adunits_get_ad_code(...)`, `adunits_list(...)`, `alerts_delete(...)`, `alerts_list(...)`, `customchannels_adunits_list(...)`, `customchannels_get(...)`, `customchannels_list(...)`, `get(...)`, `list(...)`, `payments_list(...)`, `reports_generate(...)`, `reports_saved_generate(...)`, `reports_saved_list(...)`, `savedadstyles_get(...)`, `savedadstyles_list(...)` and `urlchannels_list(...)`
// to build up your call.
let rb = hub.accounts();Implementations
Sourceimpl<'a, C> AccountMethods<'a, C>
impl<'a, C> AccountMethods<'a, C>
Sourcepub fn adclients_get_ad_code(
&self,
account_id: &str,
ad_client_id: &str,
) -> AccountAdclientGetAdCodeCall<'a, C>
pub fn adclients_get_ad_code( &self, account_id: &str, ad_client_id: &str, ) -> AccountAdclientGetAdCodeCall<'a, C>
Create a builder to help you perform the following task:
Get Auto ad code for a given ad client.
Arguments
accountId- Account which contains the ad client.adClientId- Ad client to get the code for.
Sourcepub fn adclients_list(&self, account_id: &str) -> AccountAdclientListCall<'a, C>
pub fn adclients_list(&self, account_id: &str) -> AccountAdclientListCall<'a, C>
Create a builder to help you perform the following task:
List all ad clients in the specified account.
Arguments
accountId- Account for which to list ad clients.
Sourcepub fn adunits_customchannels_list(
&self,
account_id: &str,
ad_client_id: &str,
ad_unit_id: &str,
) -> AccountAdunitCustomchannelListCall<'a, C>
pub fn adunits_customchannels_list( &self, account_id: &str, ad_client_id: &str, ad_unit_id: &str, ) -> AccountAdunitCustomchannelListCall<'a, C>
Create a builder to help you perform the following task:
List all custom channels which the specified ad unit belongs to.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client which contains the ad unit.adUnitId- Ad unit for which to list custom channels.
Sourcepub fn adunits_get(
&self,
account_id: &str,
ad_client_id: &str,
ad_unit_id: &str,
) -> AccountAdunitGetCall<'a, C>
pub fn adunits_get( &self, account_id: &str, ad_client_id: &str, ad_unit_id: &str, ) -> AccountAdunitGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the specified ad unit in the specified ad client for the specified account.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client for which to get the ad unit.adUnitId- Ad unit to retrieve.
Sourcepub fn adunits_get_ad_code(
&self,
account_id: &str,
ad_client_id: &str,
ad_unit_id: &str,
) -> AccountAdunitGetAdCodeCall<'a, C>
pub fn adunits_get_ad_code( &self, account_id: &str, ad_client_id: &str, ad_unit_id: &str, ) -> AccountAdunitGetAdCodeCall<'a, C>
Create a builder to help you perform the following task:
Get ad code for the specified ad unit.
Arguments
accountId- Account which contains the ad client.adClientId- Ad client with contains the ad unit.adUnitId- Ad unit to get the code for.
Sourcepub fn adunits_list(
&self,
account_id: &str,
ad_client_id: &str,
) -> AccountAdunitListCall<'a, C>
pub fn adunits_list( &self, account_id: &str, ad_client_id: &str, ) -> AccountAdunitListCall<'a, C>
Create a builder to help you perform the following task:
List all ad units in the specified ad client for the specified account.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client for which to list ad units.
Sourcepub fn alerts_delete(
&self,
account_id: &str,
alert_id: &str,
) -> AccountAlertDeleteCall<'a, C>
pub fn alerts_delete( &self, account_id: &str, alert_id: &str, ) -> AccountAlertDeleteCall<'a, C>
Create a builder to help you perform the following task:
Dismiss (delete) the specified alert from the specified publisher AdSense account.
Arguments
accountId- Account which contains the ad unit.alertId- Alert to delete.
Sourcepub fn alerts_list(&self, account_id: &str) -> AccountAlertListCall<'a, C>
pub fn alerts_list(&self, account_id: &str) -> AccountAlertListCall<'a, C>
Create a builder to help you perform the following task:
List the alerts for the specified AdSense account.
Arguments
accountId- Account for which to retrieve the alerts.
Sourcepub fn customchannels_adunits_list(
&self,
account_id: &str,
ad_client_id: &str,
custom_channel_id: &str,
) -> AccountCustomchannelAdunitListCall<'a, C>
pub fn customchannels_adunits_list( &self, account_id: &str, ad_client_id: &str, custom_channel_id: &str, ) -> AccountCustomchannelAdunitListCall<'a, C>
Create a builder to help you perform the following task:
List all ad units in the specified custom channel.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client which contains the custom channel.customChannelId- Custom channel for which to list ad units.
Sourcepub fn customchannels_get(
&self,
account_id: &str,
ad_client_id: &str,
custom_channel_id: &str,
) -> AccountCustomchannelGetCall<'a, C>
pub fn customchannels_get( &self, account_id: &str, ad_client_id: &str, custom_channel_id: &str, ) -> AccountCustomchannelGetCall<'a, C>
Create a builder to help you perform the following task:
Get the specified custom channel from the specified ad client for the specified account.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client which contains the custom channel.customChannelId- Custom channel to retrieve.
Sourcepub fn customchannels_list(
&self,
account_id: &str,
ad_client_id: &str,
) -> AccountCustomchannelListCall<'a, C>
pub fn customchannels_list( &self, account_id: &str, ad_client_id: &str, ) -> AccountCustomchannelListCall<'a, C>
Create a builder to help you perform the following task:
List all custom channels in the specified ad client for the specified account.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client for which to list custom channels.
Sourcepub fn payments_list(&self, account_id: &str) -> AccountPaymentListCall<'a, C>
pub fn payments_list(&self, account_id: &str) -> AccountPaymentListCall<'a, C>
Create a builder to help you perform the following task:
List the payments for the specified AdSense account.
Arguments
accountId- Account for which to retrieve the payments.
Sourcepub fn reports_saved_generate(
&self,
account_id: &str,
saved_report_id: &str,
) -> AccountReportSavedGenerateCall<'a, C>
pub fn reports_saved_generate( &self, account_id: &str, saved_report_id: &str, ) -> AccountReportSavedGenerateCall<'a, C>
Create a builder to help you perform the following task:
Generate an AdSense report based on the saved report ID sent in the query parameters.
Arguments
accountId- Account to which the saved reports belong.savedReportId- The saved report to retrieve.
Sourcepub fn reports_saved_list(
&self,
account_id: &str,
) -> AccountReportSavedListCall<'a, C>
pub fn reports_saved_list( &self, account_id: &str, ) -> AccountReportSavedListCall<'a, C>
Create a builder to help you perform the following task:
List all saved reports in the specified AdSense account.
Arguments
accountId- Account to which the saved reports belong.
Sourcepub fn reports_generate(
&self,
account_id: &str,
start_date: &str,
end_date: &str,
) -> AccountReportGenerateCall<'a, C>
pub fn reports_generate( &self, account_id: &str, start_date: &str, end_date: &str, ) -> AccountReportGenerateCall<'a, C>
Create a builder to help you perform the following task:
Generate an AdSense report based on the report request sent in the query parameters. Returns the result as JSON; to retrieve output in CSV format specify “alt=csv” as a query parameter.
Arguments
accountId- Account upon which to report.startDate- Start of the date range to report on in “YYYY-MM-DD” format, inclusive.endDate- End of the date range to report on in “YYYY-MM-DD” format, inclusive.
Sourcepub fn savedadstyles_get(
&self,
account_id: &str,
saved_ad_style_id: &str,
) -> AccountSavedadstyleGetCall<'a, C>
pub fn savedadstyles_get( &self, account_id: &str, saved_ad_style_id: &str, ) -> AccountSavedadstyleGetCall<'a, C>
Create a builder to help you perform the following task:
List a specific saved ad style for the specified account.
Arguments
accountId- Account for which to get the saved ad style.savedAdStyleId- Saved ad style to retrieve.
Sourcepub fn savedadstyles_list(
&self,
account_id: &str,
) -> AccountSavedadstyleListCall<'a, C>
pub fn savedadstyles_list( &self, account_id: &str, ) -> AccountSavedadstyleListCall<'a, C>
Create a builder to help you perform the following task:
List all saved ad styles in the specified account.
Arguments
accountId- Account for which to list saved ad styles.
Sourcepub fn urlchannels_list(
&self,
account_id: &str,
ad_client_id: &str,
) -> AccountUrlchannelListCall<'a, C>
pub fn urlchannels_list( &self, account_id: &str, ad_client_id: &str, ) -> AccountUrlchannelListCall<'a, C>
Create a builder to help you perform the following task:
List all URL channels in the specified ad client for the specified account.
Arguments
accountId- Account to which the ad client belongs.adClientId- Ad client for which to list URL channels.
Sourcepub fn get(&self, account_id: &str) -> AccountGetCall<'a, C>
pub fn get(&self, account_id: &str) -> AccountGetCall<'a, C>
Create a builder to help you perform the following task:
Get information about the selected AdSense account.
Arguments
accountId- Account to get information about.
Sourcepub fn list(&self) -> AccountListCall<'a, C>
pub fn list(&self) -> AccountListCall<'a, C>
Create a builder to help you perform the following task:
List all accounts available to this AdSense account.