Struct google_adsense1d4::api::AdCode[][src]

pub struct AdCode {
    pub ad_code: Option<String>,
    pub amp_body: Option<String>,
    pub amp_head: Option<String>,
    pub kind: Option<String>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

ad_code: Option<String>

The Auto ad code snippet. The ad code snippet.

amp_body: Option<String>

The AMP Auto ad code snippet that goes in the body of an AMP page.

amp_head: Option<String>

The AMP Auto ad code snippet that goes in the head of an AMP page.

kind: Option<String>

Kind this is, in this case adsense#adCode.