pub struct AdUnit {
pub code: Option<String>,
pub content_ads_settings: Option<AdUnitContentAdsSettings>,
pub custom_style: Option<AdStyle>,
pub feed_ads_settings: Option<AdUnitFeedAdsSettings>,
pub id: Option<String>,
pub kind: Option<String>,
pub mobile_content_ads_settings: Option<AdUnitMobileContentAdsSettings>,
pub name: Option<String>,
pub saved_style_id: Option<String>,
pub status: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- adunits get accounts (response)
- get adunits (response)
Fields
code: Option<String>Identity code of this ad unit, not necessarily unique across ad clients.
content_ads_settings: Option<AdUnitContentAdsSettings>Settings specific to content ads (AFC) and highend mobile content ads (AFMC - deprecated).
custom_style: Option<AdStyle>Custom style information specific to this ad unit.
feed_ads_settings: Option<AdUnitFeedAdsSettings>Settings specific to feed ads (AFF) - deprecated.
id: Option<String>Unique identifier of this ad unit. This should be considered an opaque identifier; it is not safe to rely on it being in any particular format.
kind: Option<String>Kind of resource this is, in this case adsense#adUnit.
mobile_content_ads_settings: Option<AdUnitMobileContentAdsSettings>Settings specific to WAP mobile content ads (AFMC) - deprecated.
name: Option<String>Name of this ad unit.
saved_style_id: Option<String>ID of the saved ad style which holds this ad unit’s style information.
status: Option<String>Status of this ad unit. Possible values are: NEW: Indicates that the ad unit was created within the last seven days and does not yet have any activity associated with it.
ACTIVE: Indicates that there has been activity on this ad unit in the last seven days.
INACTIVE: Indicates that there has been no activity on this ad unit in the last seven days.