pub struct AdUnitFeedAdsSettings {
pub ad_position: Option<String>,
pub frequency: Option<i32>,
pub minimum_word_count: Option<i32>,
pub type_: Option<String>,
}Expand description
Settings specific to feed ads (AFF) - deprecated.
This type is not used in any activity, and only used as part of another schema.
Fields
ad_position: Option<String>The position of the ads relative to the feed entries.
frequency: Option<i32>The frequency at which ads should appear in the feed (i.e. every N entries).
minimum_word_count: Option<i32>The minimum length an entry should be in order to have attached ads.
type_: Option<String>The type of ads which should appear.