pub struct Payments {
pub items: Option<Vec<Payment>>,
pub kind: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- payments list accounts (response)
- list payments (response)
Fields
items: Option<Vec<Payment>>The list of Payments for the account. One or both of a) the account’s most recent payment; and b) the account’s upcoming payment.
kind: Option<String>Kind of list this is, in this case adsense#payments.